@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
-$Id: properties.c,v 1.34 2004/02/19 00:41:43 kevinv Exp $
+$Id: properties.c,v 1.38 2004/08/16 08:44:39 davyd Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -154,9 +154,7 @@ show_status_toggled (GtkToggleButton *button, gpointer data)
   }
   
   battstat->showstatus = toggled;
-  battstat->showstatus ?
-	gtk_widget_show (battstat->statuspixmapwid):
-	gtk_widget_hide (battstat->statuspixmapwid);
+	change_orient(applet, battstat->orienttype, battstat);
   
   panel_applet_gconf_set_bool   (applet, "show_status", 
   				 battstat->showstatus, NULL);
@@ -178,12 +176,8 @@ show_percent_toggled (GtkToggleButton *button, gpointer data)
   }
   
   battstat->showpercent = toggled;
-  if (battstat->horizont) 
-    battstat->showpercent ?
-	gtk_widget_show (battstat->percent):gtk_widget_hide (battstat->percent);
-  else
-    battstat->showpercent ?
-	gtk_widget_show (battstat->statuspercent):gtk_widget_hide (battstat->statuspercent);
+	change_orient(applet, battstat->orienttype, battstat);
+	
   panel_applet_gconf_set_bool   (applet, "show_percent", 
   				 battstat->showpercent, NULL);
   				 
@@ -281,7 +275,7 @@ prefs_help_cb (GtkWindow *dialog)
      						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 	}
 
-	egg_help_display_desktop_on_screen (
+	gnome_help_display_desktop_on_screen (
 			applet_program, "battstat", "battstat", "battstatt-prefs",
 			gtk_widget_get_screen (GTK_WIDGET (dialog)),
 			&error);
@@ -336,6 +330,7 @@ prop_cb (BonoboUIComponent *uic,
   gboolean   writable;
   GConfClient *client;
   gboolean   inhibit_command_line;
+  AtkObject *atk_widget;
 
   client = gconf_client_get_default ();
   inhibit_command_line = gconf_client_get_bool (client, "/desktop/gnome/lockdown/inhibit_command_line", NULL);
@@ -492,9 +487,22 @@ prop_cb (BonoboUIComponent *uic,
   }
 
   battstat->progdir_radio = glade_xml_get_widget (glade_xml, "dir_radio_top");
+  
+  atk_widget = gtk_widget_get_accessible (battstat->progdir_radio);
+  if (GTK_IS_ACCESSIBLE (atk_widget)) {
+	  atk_object_set_name (atk_widget,
+			  _("Progress Bar Direction Moves towards top"));
+  }
+  
   g_signal_connect (G_OBJECT (battstat->progdir_radio), "toggled",
   		    G_CALLBACK (progdir_toggled), battstat);
   widget = glade_xml_get_widget (glade_xml, "dir_radio_bottom");
+  
+  atk_widget = gtk_widget_get_accessible (widget);
+  if (GTK_IS_ACCESSIBLE (atk_widget)) {
+	  atk_object_set_name (atk_widget,
+			  _("Progress Bar Direction Moves towards bottom"));
+  }
 
   if ( ! key_writable (PANEL_APPLET (battstat->applet), "drain_from_top")) {
 	  hard_set_sensitive (battstat->progdir_radio, FALSE);
