@@ -23,7 +23,6 @@
 #include <string.h>
 
 #include <libgnome/gnome-exec.h>
-#include <egg-screen-exec.h>
 
 #include <glib.h>
 #include <gdk/gdk.h>
@@ -83,7 +82,7 @@ mc_exec_command (MCData     *mc,
 		g_error_free (error);
 }
 
-void beep ()
+void beep (void)
 {
 	GConfClient *default_client;
 	gboolean audible_bell_set;
