@@ -83,6 +83,9 @@ typedef struct
 	gboolean prelighted;		/* Whether applet is prelighted */
 	gboolean pressed;		/* Whether applet is pressed */
 
+	gint panel_size;
+	PanelAppletOrient panel_orient;
+
 } StickyNotesApplet;
 	
 typedef enum
@@ -96,15 +99,15 @@ typedef enum
 extern StickyNotes *stickynotes;
 
 void stickynotes_applet_init(PanelApplet *panel_applet);
-void stickynotes_applet_init_icons();
-void stickynotes_applet_init_prefs();
+void stickynotes_applet_init_icons(void);
+void stickynotes_applet_init_prefs(void);
 
 StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet);
 
 void stickynotes_applet_update_icon(StickyNotesApplet *applet);
-void stickynotes_applet_update_prefs();
-void stickynotes_applet_update_menus();
-void stickynotes_applet_update_tooltips();
+void stickynotes_applet_update_prefs(void);
+void stickynotes_applet_update_menus(void);
+void stickynotes_applet_update_tooltips(void);
 
 void stickynotes_applet_do_default_action(GdkScreen *screen);
 
